#' Identification of somatic mutation-driven immune cells
#' @description With the use of functions in this packages, users could identify the immune cells driven by somatic mutations in tumor microenvironment.
#' @name SMDIC-package
#' @aliases SMDIC-package
#' @import RColorBrewer
#' @import survminer
#' @import backports
#' @docType package
"_PACKAGE"
